# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [v0.0.1] - 2024-12-25
### :construction_worker: Build System
- [`48e11e8`](https://github.com/kiyoon/version-pioneer/commit/48e11e87e2af9090ccea9708e7ff0581656db6d6) - codecov, lockfile update, pyproject *(commit by [@kiyoon](https://github.com/kiyoon))*

### :memo: Documentation Changes
- [`389ca13`](https://github.com/kiyoon/version-pioneer/commit/389ca1308e6a4533bde2370879967bc65b655f48) - overall rewrite (minor) *(commit by [@kiyoon](https://github.com/kiyoon))*

[v0.0.1]: https://github.com/kiyoon/version-pioneer/compare/v0.0.0...v0.0.1
